@@ -5,7 +5,7 @@ from ...fields.video import EmbeddedVideoField
 from ..arm_content_support.models import SimpleMixedinVideoModel
 
 
-class EmbeddedVideoMixinTestCase(TestCase):
+class EmbeddedVideoMixinTestCase(ArmContentTestCase):
     def test_model_has_video_field(self):
         model = SimpleMixedinVideoModel.objects.create()
         self.assertModelHasField(model, "video", EmbeddedVideoField)
